# keys-management

KeysManagemets is a layer tool to ease the usage of application secret keys.
It allows to define multiple secret key,  from various sources if required, for each use case.
After keys definitions, the tool provides methods to support secret keys rotation when needed.
